@@ -79,3 +79,6 @@ for i in $CHNG; do
   mkdir -p $(dirname $j)
   ln -s $i $j
 done
+
+# Recreate udev (needed for kernel >2.6.8)
+[ -x /etc/init.d/udev ] && /etc/init.d/udev start
